## ecr.commands.cmd_pwd

src/ecr/commands/cmd_pwd.py
    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    from .. import shared, ui
    from ..ui.command import Command, Namespace, ReturnCode

    class PwdCommand(Command):
        @staticmethod
        def default(args: Namespace)->ReturnCode:  # pylint: disable=W0613
            console = ui.getConsole()
            console.write(shared.getCwd())
            return ReturnCode.OK

        def __init__(self):
            super().__init__("pwd", help="Print working directory", func=PwdCommand.default)